==> dropwizard-guicey-6.3.1-sources.jar: ru/vyarus/dropwizard/guice/module/context/bootstrap/BootstrapProxyFactory.java <==
package ru.vyarus.dropwizard.guice.module.context.bootstrap;

import io.dropwizard.core.Application;
import io.dropwizard.core.ConfiguredBundle;
import io.dropwizard.core.setup.Bootstrap;
import javassist.util.proxy.Proxy;
import javassist.util.proxy.ProxyFactory;
import ru.vyarus.dropwizard.guice.module.context.ConfigurationContext;
import ru.vyarus.dropwizard.guice.module.installer.util.InstanceUtils;

/**
 * {@link Bootstrap} proxy delegates all calls directly to bootstrap object, except bundle addition. Instead,
 * bundle addition is replaced with guicey bundle registration so disable and deduplication rules could be
 * applied for transitive dropwizard bundles.
 *
 * @author Vyacheslav Rusakov
 * @since 07.05.2019
 */
public final class BootstrapProxyFactory {

    private BootstrapProxyFactory() {
    }

    /**
     * @param bootstrap dropwizard bootstrap object
     * @param context   guicey configuration context
     * @return dropwizard bootstrap proxy object
     */
    @SuppressWarnings("unchecked")
    public static Bootstrap create(final Bootstrap bootstrap, final ConfigurationContext context) {
        try {
            final ProxyFactory factory = new ProxyFactory();
            factory.setSuperclass(Bootstrap.class);
            final Class proxy = factory.createClass();

            final Bootstrap res = (Bootstrap) InstanceUtils.createWithNulls(proxy, Application.class);
            ((Proxy) res).setHandler((self, thisMethod, proceed, args) -> {
                // intercept only bundle addition
                if ("addBundle".equals(thisMethod.getName())) {
                    context.registerDropwizardBundles((ConfiguredBundle) args[0]);
                    return null;
                }
                // other methods called as is
                return thisMethod.invoke(bootstrap, args);
            });
            return res;
        } catch (Exception e) {
            throw new IllegalStateException("Failed to create Bootstrap proxy", e);
        }
    }
}

==> dropwizard-guicey-7.0.2-sources.jar: ru/vyarus/dropwizard/guice/module/context/bootstrap/BootstrapProxyFactory.java <==
package ru.vyarus.dropwizard.guice.module.context.bootstrap;

import io.dropwizard.core.Application;
import io.dropwizard.core.ConfiguredBundle;
import io.dropwizard.core.setup.Bootstrap;
import javassist.util.proxy.Proxy;
import javassist.util.proxy.ProxyFactory;
import ru.vyarus.dropwizard.guice.module.context.ConfigurationContext;

/**
 * {@link Bootstrap} proxy delegates all calls directly to bootstrap object, except bundle addition. Instead,
 * bundle addition is replaced with guicey bundle registration so disable and deduplication rules could be
 * applied for transitive dropwizard bundles.
 *
 * @author Vyacheslav Rusakov
 * @since 07.05.2019
 */
public final class BootstrapProxyFactory {

    private BootstrapProxyFactory() {
    }

    /**
     * @param bootstrap dropwizard bootstrap object
     * @param context   guicey configuration context
     * @return dropwizard bootstrap proxy object
     */
    @SuppressWarnings("unchecked")
    public static Bootstrap create(final Bootstrap bootstrap, final ConfigurationContext context) {
        try {
            final ProxyFactory factory = new ProxyFactory();
            factory.setSuperclass(Bootstrap.class);
            final Class proxy = factory.createClass();

            final Bootstrap res = (Bootstrap) proxy.getConstructor(Application.class).newInstance(new Object[]{null});
            ((Proxy) res).setHandler((self, thisMethod, proceed, args) -> {
                // intercept only bundle addition
                if ("addBundle".equals(thisMethod.getName())) {
                    context.registerDropwizardBundles((ConfiguredBundle) args[0]);
                    return null;
                }
                // other methods called as is
                return thisMethod.invoke(bootstrap, args);
            });
            return res;
        } catch (Exception e) {
            throw new IllegalStateException("Failed to create Bootstrap proxy", e);
        }
    }
}
